==> better-admin-ui-vue-0.0.9.tgz: package/es/components/Form/Form.js <==
import _mergeJSXProps6 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps5 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps4 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps3 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

/**
 * @Date: 2020-05-20 09:42
 * @Author: Fioanna
 * @Description: 高级表单
 */
import { FORM_ITEM_TYPE } from './constants';
import { formProps } from './types';
import FormMixin from './Form.mixin';
import ECascader from '../Cascader';
import EMultipleSelect from '../MultipleSelect';
import EFileUpload from '../FileUpload';
import ETextarea from '../TextArea';
import AFormModal from 'ant-design-vue/es/form-model'; // 用于展示的时间格式化,  HH:mm:ss

var DEFAULT_SHOW_FORMAT = 'YYYY-MM-DD'; // 用于发送协议的时间格式，如有需要item传入postFormat参数

var DEFAULT_VALUE_FORMAT = 'YYYYMMDD';
var AFormModalItem = AFormModal.Item;
export default {
  name: 'EForm',
  mixins: [FormMixin],
  props: formProps,
  computed: {
    formWrapperSpan: function formWrapperSpan() {
      return this.$props.totalSpan - this.$props.labelSpan;
    },
    // 表单按钮栏的样式
    formBtnLayout: function formBtnLayout() {
      return {
        lg: {
          span: this.formWrapperSpan,
          offset: this.$props.labelSpan
        },
        sm: {
          span: this.formWrapperSpan,
          offset: this.$props.labelSpan
        }
      };
    },
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        model: this.form,
        labelCol: {
          lg: {
            span: this.$props.labelSpan
          },
          sm: {
            span: this.$props.labelSpan
          }
        },
        wrapperCol: {
          lg: {
            span: this.formWrapperSpan
          },
          sm: {
            span: this.formWrapperSpan
          }
        }
      };
    }
  },
  render: function render() {
    var h = arguments[0];

    if (this.hasFieldList) {
      return h(AFormModal, _mergeJSXProps([{
        ref: "advancedForm",
        "class": "e-form"
      }, {
        props: this.formModelBind
      }]), [this._renderFormContent()]);
    }

    return null;
  },
  methods: {
    // 解析完表单项列表的操作
    _doAfterParseFieldList: function _doAfterParseFieldList() {
      var _this = this;

      if (this.validError) {
        this.$nextTick(function () {
          _this.validate().then(function () {})["catch"](function () {});
        });
      }
    },
    // 判断formItem是否不可编辑
    _isDisabled: function _isDisabled(fieldItem) {
      if (fieldItem.props && fieldItem.props.disabled) {
        // 如果该项的属性就是不可编辑返回true
        return true;
      }

      if (this.isOnlyEditUpload) {
        // 如果是只能更新图片的状态，则传入不可编辑的字段生效
        var key = fieldItem.key,
            keys = fieldItem.keys,
            children = fieldItem.children;

        if (key && this.disabledKeyList.includes(key)) {
          // 有key的话，判断key是否在不可编辑列表中
          return true;
        }

        if (keys && this.disabledKeyList.includes(keys[0])) {
          return true;
        }

        if (children && this.disabledKeyList.includes(children[0].key)) {
          return true;
        }
      }

      return false;
    },
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props, newForm, newItem) {
      props.showFormat = props.showFormat || DEFAULT_SHOW_FORMAT;
      props.valueFormat = props.valueFormat || DEFAULT_VALUE_FORMAT;
      var key = newItem.key;

      if (!newItem.keys) {
        newItem.keys = [key + '1', key + '2'];
      }

      var keys = newItem.keys;

      if (newForm[keys[0]] && newForm[keys[1]]) {
        newForm[key] = 'true';
      }
    },
    // 下拉多选
    _parseSelectMultiple: function _parseSelectMultiple(item, props, newForm, newItem) {
      this._parseSelect(item, props, newForm, newItem);
    },
    // 解析文件上传
    _parseFileUpload: function _parseFileUpload(item, props, newForm, newItem) {
      if (item.children) {
        // 如果是多张图片要设置组都key和值，用于require判断
        var targetKey = item.children[0].key + 'List';
        newItem.key = targetKey;
        newForm[targetKey] = 'true';
      }
    },
    // 初始化表单的单项
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      var h = this.$createElement;
      var key = fieldItem.key,
          label = fieldItem.label,
          rules = fieldItem.rules;
      return h(AFormModalItem, {
        key: index,
        attrs: {
          label: label,
          prop: key,
          rules: rules
        }
      }, [this._renderFormItemContent(fieldItem)]);
    },
    // 初始化表单footer的按钮部分，提交重置按钮，可继承修改
    _renderFormFooter: function _renderFormFooter() {
      var h = this.$createElement;
      return h(AFormModalItem, {
        attrs: {
          wrapperCol: this.formBtnLayout
        }
      }, [this.$scopedSlots.footer]);
    },
    // 初始化多行文本输入框
    _renderTextarea: function _renderTextarea(fieldItem) {
      var _this2 = this;

      var h = this.$createElement;
      // return this._renderInput(fieldItem, true)
      return h(ETextarea, _mergeJSXProps2([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "input": function input(value) {
            _this2._emitChange(fieldItem.key, value);
          }
        }
      }]));
    },
    // 初始化多选下拉框
    _renderSelectMultiple: function _renderSelectMultiple(fieldItem) {
      var _this3 = this;

      var h = this.$createElement;
      return h(EMultipleSelect, _mergeJSXProps3([{
        ref: fieldItem.key
      }, {
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, label, option) {
            _this3._selectChange(fieldItem, value, label, option);
          }
        }
      }]));
    },
    // 初始化下拉选择框
    _renderCascader: function _renderCascader(fieldItem) {
      var _this4 = this;

      var h = this.$createElement;
      return h(ECascader, _mergeJSXProps4([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, label) {
            _this4._selectChange(fieldItem, value, label);
          }
        }
      }]));
    },
    // 初始化图片上传
    _renderFileUpload: function _renderFileUpload(fieldItem) {
      var _this5 = this;

      var h = this.$createElement;

      if (fieldItem.children) {
        return h("div", {
          "class": "file-upload-wrapper"
        }, [fieldItem.children.map(function (child, keyIndex) {
          return h(AFormModalItem, {
            style: "margin: 0",
            key: keyIndex,
            attrs: {
              prop: child.key,
              rules: child.rules
            }
          }, [h(EFileUpload, _mergeJSXProps5([{
            props: fieldItem.props
          }, {
            attrs: {
              ossClient: _this5.$props.ossClient,
              description: child.placeholder,
              value: _this5.form[child.key]
            },
            on: {
              "input": function input(value) {
                _this5._emitChange(fieldItem.key, value);
              }
            }
          }]))]);
        })]);
      }

      return h(EFileUpload, _mergeJSXProps6([{
        props: fieldItem.props
      }, {
        attrs: {
          ossClient: this.$props.ossClient,
          description: fieldItem.placeholder,
          value: this.form[fieldItem.key]
        },
        on: {
          "input": function input(value) {
            _this5._emitChange(fieldItem.key, value);
          }
        }
      }]));
    },
    // 将值添加到结果表单中
    _addValueToResForm: function _addValueToResForm(resForm, key) {
      if (this.form[key] !== undefined && this.form[key] !== null) {
        resForm[key] = this.form[key];
      }
    },

    /**
     * 获取表单数据
     * @returns {form|{}}
     */
    getValue: function getValue() {
      var _this6 = this;

      var resForm = {}; // 只有非空到值才会设置到resForm中

      this.fieldList.forEach(function (fieldItem) {
        if (fieldItem.keys) {
          // 针对选择器
          fieldItem.keys.forEach(function (key) {
            _this6._addValueToResForm(resForm, key);
          });
        }

        if (fieldItem.children) {
          // 文件上传，子元素
          fieldItem.children.forEach(function (child) {
            var childKey = child.key;

            _this6._addValueToResForm(resForm, childKey);
          });
        } else if (fieldItem.type !== FORM_ITEM_TYPE.DATE_RANGE) {
          // 如果是时间区间选择则key不存入
          var key = fieldItem.key;

          _this6._addValueToResForm(resForm, key);
        }
      });
      return resForm;
    }
  }
};

==> better-admin-ui-vue-0.0.12.tgz: package/es/components/Form/Form.js <==
import _mergeJSXProps7 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps6 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps5 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps4 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps3 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

/**
 * @Date: 2020-05-20 09:42
 * @Author: Fioanna
 * @Description: 高级表单
 */
import AFormModal from 'ant-design-vue/es/form-model';
import ACheckboxGroup from 'ant-design-vue/es/checkbox/Group';
import { FORM_ITEM_TYPE } from './constants';
import { formProps } from './types';
import FormMixin from './Form.mixin';
import ECascader from '../Cascader';
import EMultipleSelect from '../MultipleSelect';
import EFileUpload from '../FileUpload';
import ETextarea from '../TextArea'; // 用于展示的时间格式化,  HH:mm:ss

var DEFAULT_SHOW_FORMAT = 'YYYY-MM-DD'; // 用于发送协议的时间格式，如有需要item传入postFormat参数

var DEFAULT_VALUE_FORMAT = 'YYYYMMDD';
var AFormModalItem = AFormModal.Item;
export default {
  name: 'EForm',
  mixins: [FormMixin],
  props: formProps,
  computed: {
    formWrapperSpan: function formWrapperSpan() {
      return this.$props.totalSpan - this.$props.labelSpan;
    },
    // 表单按钮栏的样式
    formBtnLayout: function formBtnLayout() {
      return {
        lg: {
          span: this.formWrapperSpan,
          offset: this.$props.labelSpan
        },
        sm: {
          span: this.formWrapperSpan,
          offset: this.$props.labelSpan
        }
      };
    },
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        model: this.form,
        labelCol: {
          lg: {
            span: this.$props.labelSpan
          },
          sm: {
            span: this.$props.labelSpan
          }
        },
        wrapperCol: {
          lg: {
            span: this.formWrapperSpan
          },
          sm: {
            span: this.formWrapperSpan
          }
        }
      };
    }
  },
  render: function render() {
    var h = arguments[0];

    if (this.hasFieldList) {
      return h(AFormModal, _mergeJSXProps([{
        ref: "advancedForm",
        "class": "e-form"
      }, {
        props: this.formModelBind
      }]), [this._renderFormContent()]);
    }

    return null;
  },
  methods: {
    // 解析完表单项列表的操作
    _doAfterParseFieldList: function _doAfterParseFieldList() {
      var _this = this;

      if (this.validError) {
        this.$nextTick(function () {
          _this.validate().then(function () {})["catch"](function () {});
        });
      }
    },
    // 判断formItem是否不可编辑
    _isDisabled: function _isDisabled(fieldItem) {
      if (fieldItem.props && fieldItem.props.disabled) {
        // 如果该项的属性就是不可编辑返回true
        return true;
      }

      if (this.isOnlyEditUpload) {
        // 如果是只能更新图片的状态，则传入不可编辑的字段生效
        var key = fieldItem.key,
            keys = fieldItem.keys,
            children = fieldItem.children;

        if (key && this.disabledKeyList.includes(key)) {
          // 有key的话，判断key是否在不可编辑列表中
          return true;
        }

        if (keys && this.disabledKeyList.includes(keys[0])) {
          return true;
        }

        if (children && this.disabledKeyList.includes(children[0].key)) {
          return true;
        }
      }

      return false;
    },
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props, newForm, newItem) {
      props.showFormat = props.showFormat || DEFAULT_SHOW_FORMAT;
      props.valueFormat = props.valueFormat || DEFAULT_VALUE_FORMAT;
      var key = newItem.key;

      if (!newItem.keys) {
        newItem.keys = [key + '1', key + '2'];
      }

      var keys = newItem.keys;

      if (newForm[keys[0]] && newForm[keys[1]]) {
        newForm[key] = 'true';
      }
    },
    // 下拉多选
    _parseSelectMultiple: function _parseSelectMultiple(item, props, newForm, newItem) {
      this._parseSelect(item, props, newForm, newItem);
    },
    // 解析文件上传
    _parseFileUpload: function _parseFileUpload(item, props, newForm, newItem) {
      if (item.children) {
        // 如果是多张图片要设置组都key和值，用于require判断
        var targetKey = item.children[0].key + 'List';
        newItem.key = targetKey;
        newForm[targetKey] = 'true';
      }
    },
    // 初始化表单的单项
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      var h = this.$createElement;
      var key = fieldItem.key,
          label = fieldItem.label,
          rules = fieldItem.rules;
      return h(AFormModalItem, {
        key: index,
        attrs: {
          label: label,
          prop: key,
          rules: rules
        }
      }, [this._renderFormItemContent(fieldItem)]);
    },
    // 初始化表单footer的按钮部分，提交重置按钮，可继承修改
    _renderFormFooter: function _renderFormFooter() {
      var h = this.$createElement;
      return h(AFormModalItem, {
        attrs: {
          wrapperCol: this.formBtnLayout
        }
      }, [this.$scopedSlots.footer]);
    },
    // 初始化多行文本输入框
    _renderTextarea: function _renderTextarea(fieldItem) {
      var _this2 = this;

      var h = this.$createElement;
      // return this._renderInput(fieldItem, true)
      return h(ETextarea, _mergeJSXProps2([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "input": function input(value) {
            _this2._emitChange(fieldItem.key, value);
          }
        }
      }]));
    },
    // 初始化多选框
    _renderCheckBox: function _renderCheckBox(fieldItem) {
      var _this3 = this;

      var h = this.$createElement;
      return h(ACheckboxGroup, _mergeJSXProps3([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(checkedValue) {
            // this._radioChange(fieldItem, checkedValue)
            _this3._emitChange(fieldItem.key, checkedValue);
          }
        }
      }]));
    },
    // 初始化多选下拉框
    _renderSelectMultiple: function _renderSelectMultiple(fieldItem) {
      var _this4 = this;

      var h = this.$createElement;
      return h(EMultipleSelect, _mergeJSXProps4([{
        ref: fieldItem.key
      }, {
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, label, option) {
            _this4._selectChange(fieldItem, value, label, option);
          }
        }
      }]));
    },
    // 初始化下拉选择框
    _renderCascader: function _renderCascader(fieldItem) {
      var _this5 = this;

      var h = this.$createElement;
      return h(ECascader, _mergeJSXProps5([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, label) {
            _this5._selectChange(fieldItem, value, label);
          }
        }
      }]));
    },
    // 初始化图片上传
    _renderFileUpload: function _renderFileUpload(fieldItem) {
      var _this6 = this;

      var h = this.$createElement;

      if (fieldItem.children) {
        return h("div", {
          "class": "file-upload-wrapper"
        }, [fieldItem.children.map(function (child, keyIndex) {
          return h(AFormModalItem, {
            style: "margin: 0",
            key: keyIndex,
            attrs: {
              prop: child.key,
              rules: child.rules
            }
          }, [h(EFileUpload, _mergeJSXProps6([{
            props: fieldItem.props
          }, {
            attrs: {
              ossClient: _this6.$props.ossClient,
              description: child.placeholder,
              value: _this6.form[child.key]
            },
            on: {
              "input": function input(value) {
                _this6._emitChange(fieldItem.key, value);
              }
            }
          }]))]);
        })]);
      }

      return h(EFileUpload, _mergeJSXProps7([{
        props: fieldItem.props
      }, {
        attrs: {
          ossClient: this.$props.ossClient,
          description: fieldItem.placeholder,
          value: this.form[fieldItem.key]
        },
        on: {
          "input": function input(value) {
            _this6._emitChange(fieldItem.key, value);
          }
        }
      }]));
    },
    // 将值添加到结果表单中
    _addValueToResForm: function _addValueToResForm(resForm, key) {
      if (this.form[key] !== undefined && this.form[key] !== null) {
        resForm[key] = this.form[key];
      }
    },

    /**
     * 获取表单数据
     * @returns {form|{}}
     */
    getValue: function getValue() {
      var _this7 = this;

      var resForm = {}; // 只有非空到值才会设置到resForm中

      this.fieldList.forEach(function (fieldItem) {
        if (fieldItem.keys) {
          // 针对选择器
          fieldItem.keys.forEach(function (key) {
            _this7._addValueToResForm(resForm, key);
          });
        }

        if (fieldItem.children) {
          // 文件上传，子元素
          fieldItem.children.forEach(function (child) {
            var childKey = child.key;

            _this7._addValueToResForm(resForm, childKey);
          });
        } else if (fieldItem.type !== FORM_ITEM_TYPE.DATE_RANGE) {
          // 如果是时间区间选择则key不存入
          var key = fieldItem.key;

          _this7._addValueToResForm(resForm, key);
        }
      });
      return resForm;
    }
  }
};
